pub struct PtyConsole { /* private fields */ }Expand description
PTY (pseudo-terminal) console backend.
Provides a real terminal interface that can be connected to by terminal emulators or the host shell.
Implementations
Sourceimpl PtyConsole
impl PtyConsole
Sourcepub fn slave_path(&self) -> &str
pub fn slave_path(&self) -> &str
Returns the path to the slave PTY device.
Users can connect to this path with a terminal emulator:
screen /dev/pts/Xminicom -D /dev/pts/X
Sourcepub fn set_nonblocking(&mut self, nonblocking: bool) -> Result<()>
pub fn set_nonblocking(&mut self, nonblocking: bool) -> Result<()>
Sets non-blocking mode on the master.