VirtioConsole

Struct VirtioConsole 

pub struct VirtioConsole { /* private fields */ }
VirtIO console device.

Implementations

Source

impl VirtioConsole

pub const FEATURE_SIZE: u64

Feature: Console size.

pub const FEATURE_MULTIPORT: u64

Feature: Multiport.

pub const FEATURE_EMERG_WRITE: u64

Feature: Emergency write.

pub const FEATURE_VERSION_1: u64

VirtIO 1.0 feature.

pub fn new(config: ConsoleConfig) -> Self

Creates a new console device.

pub fn with_stdio() -> Self

Creates a console with standard I/O.

pub fn set_io(&mut self, io: Arc<Mutex<dyn ConsoleIo>>)

Sets the console I/O handler.

pub fn queue_input(&mut self, data: &[u8]) -> Result<()>

Queues input data to be read by the guest.

Errors

Returns an error if the console is not active.

pub fn read_output(&mut self) -> Vec<u8>

Reads output data written by the guest.

pub fn process_tx_queue(&mut self, memory: &[u8]) -> Result<Vec<(u16, u32)>>

Processes the transmit queue.

Errors

Returns an error if processing fails.

pub fn rx_available(&self) -> usize

Gets the number of bytes available for RX.